@@ -2,35 +2,35 @@
 getnext.comb <- function(I, d=1L, drop=TRUE){
     if (d*I$r>.Machine$integer.max) stop("d is too large.")
     if(I$status>0){
-        I$status = -1L
+        I$status <- -1L
         return(NULL)
     }
     if (I$replace){
         if (I$status==-1L) {
-            I$currInd = rep(0L,I$r)
+            I$currInd <- rep(0L,I$r)
         }
-        C = next_combinations_replace(I$currInd, I$unique_n, d, I$status)
+        C <- next_combinations_replace(I$currInd, I$unique_n, d, I$status)
     }else{
         if (I$status==-1L) {
-            if(I$is.multiset){
+            if (I$is.multiset){
                 # add 0L to blame lazy evaluation
-                I$currInd = I$multiset[1:I$r] + 0L
+                I$currInd <- I$multiset[1:I$r] + 0L
             }else{
-                I$currInd = (1:I$r)-1L
+                I$currInd <- (1:I$r)-1L
             }
         }
         if (I$is.multiset){
-            C = next_multiset_combinations(I$multiset, I$currInd, d, I$status)
+            C <- next_multiset_combinations(I$multiset, I$currInd, d, I$status)
         }else{
-            C = next_combinations(I$currInd, I$n, d, I$status)
+            C <- next_combinations(I$currInd, I$n, d, I$status)
         }
     }
     if(is.null(C)){
-        I$status = -1L
+        I$status <- -1L
         return(NULL)
-    }else if(I$status>0){
-        C = C[1:I$status,,drop=FALSE]
-        d = I$status
+    }else if (I$status>0){
+        C <- C[1:I$status,,drop=FALSE]
+        d <- I$status
     }
     if (is.null(I$labels)){
         if (drop || d>1){
