@@ -1,6 +1,6 @@
-#' Calculate mulinomial coefficient
+#' Calculate multinomial coefficient
 #'
-#' This function calculate the multinomial coefficient
+#' This function calculates the multinomial coefficient
 #' \deqn{\frac{(\sum n_j)!}{\prod n_j!}.}{(\sum n_j)! / \prod n_j!.}
 #' where \eqn{n_j}{n_j}'s are the number of multiplicities in the multiset.
 #'
@@ -16,7 +16,7 @@ multichoose <- function(n){
 }
 
 
-#' Calcuate the number of r-permutations of a multiset
+#' Calculate the number of r-permutations of a multiset
 #' @param f the frequencies of the mutliset
 #' @param r the number of object drawn from the multiset
 #' @return the number of r-permutations
@@ -28,31 +28,56 @@ multichoose <- function(n){
 #' @import polynom
 np_multiset <- function(f, r){
     p <- polynomial(1)
-    alpha = lgamma(r+1)/length(f)
-    for(i in f){
-        j = pmin(i, r)
-        p <- p * polynomial(exp(c(alpha,alpha-lgamma((1:j)+1))))
+    alpha <- lgamma(r+1)/length(f)
+    for (i in f){
+        j <- pmin(i, r)
+        p <- p * polynomial(exp(c(alpha,alpha-lgamma( (1:j)+1) )))
         p <- polynomial(p[1:min(length(p),r+1)])
     }
     return(round(p[r+1]))
 }
 
 
-#' Calcuate the number of combinations of a multiset
+#' Calculate the number of r-combinations of a multiset
 #' @param f the frequencies of the mutliset
 #' @param r the number of object drawn from the multiset
 #' @return the number of combinations
 #' @examples
-#' x = c("a","a","b")
+#' x <- c("a","a","b")
 #' # possible combinations of size 2 are "aa" and "ab".
-#' nc_multiset(table(x), 2) # = 2
+#' nc_multiset(table(x), 2) # <- 2
 #' @export
 #' @import polynom
 nc_multiset <- function(f, r){
     p <- polynomial(1)
-    for(i in f){
+    for (i in f){
         p <- p * polynomial(rep.int(1, i + 1))
         p <- polynomial(p[1:min(length(p),r+1)])
     }
     return(p[r+1])
 }
+
+#' Wrap iterpc objects by iterators::iter
+#' @param I the iterpc object
+#' @param d number of permutation(s)/combination(s) wanted in each iteration, default to 1
+#' @return a iter object compartible with iterators package
+#' @import iterators
+#' @examples
+#' library(iterators)
+#' I <- iterpc(5, 2)
+#' it <- iter_wrapper(I)
+#' nextElem(it)
+#' nextElem(it)
+#'
+#' library(foreach)
+#' I <- iterpc(5, 2)
+#' it <- iter_wrapper(I)
+#' foreach(x=it, .combine=c) %do% { sum(x) }
+#' @export
+iter_wrapper <- function(I, d=1){
+    iter(function() {
+        out <- getnext(I, d)
+        !is.null(out) || stop("StopIteration", call. = FALSE)
+        out
+    })
+}
